@@ -1140,28 +1140,42 @@ class Series(ABC):
         operation: str,
         fmt_str: str,
         other_dtypes: Tuple[str, ...] = (),
-        dtype: Optional[Union[str, Mapping[str, Optional[str]]]] = None
+        dtype: Optional[Union[str, Mapping[str, Optional[str]]]] = None,
+        strict_other_dtypes: Tuple[str, ...] = ()
     ) -> 'Series':
         """
         The standard way to perform a binary operation
 
-        :param self: SeriesSubTypehe left hand side expression (lhs) in the operation
+        :param self: SeriesSubType: the left hand side expression (lhs) in the operation
         :param other: The right hand side expression (rhs) in the operation
         :param operation: A user-readable representation of the operation
         :param fmt_str: An Expression.construct format string, accepting lhs and rhs as the only parameters,
             in that order.
-        :param other_dtypes: The acceptable dtypes for the rhs expression
+        :param other_dtypes: The acceptable dtypes for the rhs expression. There will be
+            an explicit cast/astype to lhs; we accept the type as rhs for this operation. If the DB
+            does not know what to do with the types in the operation, explicit type conversions can be done
+            using the `strict_other_dtypes` parameter.
         :param dtype: The new dtype for the Series that results from this operation. Leave None for same
             as lhs, pass a string with the new explicit dtype, or pass a dict that maps rhs.dtype to the
             resulting dtype. If the dict does not contain the rhs.dtype, None is assumed, using the lhs
             dtype.
+        :param strict_other_dtypes: list of dtypes that are accepted directly into the rhs, all other ones
+            (from `other_dtypes`) will be cast to lhs.dtype before the operation. Defaults to
+            `other_dtypes` if none given.
         """
         if len(other_dtypes) == 0:
             raise NotImplementedError(f'binary operation {operation} not supported '
                                       f'for {self.__class__} and {other.__class__}')
 
+        if len(strict_other_dtypes) == 0:
+            strict_other_dtypes = other_dtypes
+
         other = value_to_series(base=self, value=other)
         self_modified, other = self._get_supported(operation, other_dtypes, other)
+
+        if other.dtype not in strict_other_dtypes:
+            other = other.astype(self_modified.dtype)
+
         expression = NonAtomicExpression.construct(fmt_str, self_modified, other)
 
         new_dtype: Optional[str]
@@ -1249,7 +1263,8 @@ class Series(ABC):
         self,
         other: Union['Series', AllSupportedLiteralTypes],
         comparator: str,
-        other_dtypes: Tuple[str, ...] = ()
+        other_dtypes: Tuple[str, ...] = (),
+        strict_other_dtypes: Tuple[str, ...] = (),
     ) -> 'SeriesBoolean':
         if len(other_dtypes) == 0:
             raise TypeError(f'comparator {comparator} not supported for '
@@ -1257,7 +1272,7 @@ class Series(ABC):
         return cast('SeriesBoolean', self._binary_operation(
             other=other, operation=f"comparator '{comparator}'",
             fmt_str=f'{{}} {comparator} {{}}',
-            other_dtypes=other_dtypes, dtype='bool'
+            other_dtypes=other_dtypes, dtype='bool', strict_other_dtypes=strict_other_dtypes
         ))
 
     def __ne__(self, other: Union['Series', AllSupportedLiteralTypes]) -> 'SeriesBoolean':   # type: ignore
