@@ -208,7 +208,13 @@ class SeriesJson(Series):
         if is_bigquery(dialect):
             if source_dtype in ('json', 'string'):
                 return expression
-            raise ValueError(f'cannot convert {source_dtype} to json')
+            elif source_dtype in ('dict', 'list'):
+                # BQ can convert most types into json format, and since we use string as the container
+                # in our BQ implementation, this is basically a cast.
+                # https://cloud.google.com/bigquery/docs/reference/standard-sql/json_functions#to_json_string
+                return Expression.construct(f'to_json_string({{}})', expression)
+            else:
+                raise ValueError(f'cannot convert {source_dtype} to json')
         raise DatabaseNotSupportedException(dialect)
 
     def to_pandas_info(self) -> Optional['ToPandasInfo']:
@@ -232,26 +238,24 @@ class SeriesJson(Series):
         self,
         other: Union['Series', AllSupportedLiteralTypes],
         comparator: str,
-        other_dtypes=tuple()
+        other_dtypes=tuple(),
+        strict_other_dtypes=tuple()
     ) -> 'SeriesBoolean':
         if is_postgres(self.engine):
             other_dtypes = ('json_postgres', 'json', 'string')
-            fmt_str = f'cast({{}} as jsonb) {comparator} cast({{}} as jsonb)'
+            strict_other_dtypes = tuple(['json_postgres'])
         elif is_athena(self.engine):
-            # TODO: support string here to for compatibility with other databases
-            #  https://github.com/objectiv/objectiv-analytics/issues/1142
-            other_dtypes = ('json')
-            fmt_str = f'{{}} {comparator} {{}}'
+            other_dtypes = ('json', 'string')
+            strict_other_dtypes = tuple(['json'])
         elif is_bigquery(self.engine):
             other_dtypes = ('json', 'string')
-            fmt_str = f'{{}} {comparator} {{}}'
         else:
             raise DatabaseNotSupportedException(self.engine)
 
         result = self._binary_operation(
             other, operation=f"comparator '{comparator}'",
-            fmt_str=fmt_str,
-            other_dtypes=other_dtypes, dtype='bool'
+            fmt_str=f'{{}} {comparator} {{}}',
+            other_dtypes=other_dtypes, dtype='bool', strict_other_dtypes=strict_other_dtypes
         )
         return cast('SeriesBoolean', result)  # we told _binary_operation to return dtype='bool'
 
